---
title: Lántas—Nouns
backname: Lántas
backlink: ../laantas
...

Nouns are the words which name and refer to specific entities. Lántas is unusual in that words which are often considered to form a separate "adjective" class, or, occasionally, a subset of verbs, are also (the genitive case of) nouns.

# Number

The basic form of a noun is its singular, in all cases. The plural is formed by adding:

* «-al» to a word ending in «l» or «ł»,
* «-l» to a word ending in a vowel, or
* «-ł» to a word ending in a consonant, syllabic or not, other than «l».

This plural form can also be applied to names of people. In this case it forms what is called an _associative plural_, and refers to a person plus a group associated with them, usually their family or friend group.

<figure class=glosses>
```gloss
ǧunail
ǧunai-l
stick-PL
sticks
```
```gloss
Jánimł
Jáni-m-ł
John-DEF-PL
John and his friends
```
</figure>

# Core cases {#corecases}

Declension for the core cases of «nú» 'man' and «lun» 'road' are shown below. Some of the endings are slightly different in the case of a stem ending in a consonant or vowel, and if the ending starts with multiple consonants the final one of the stem is dropped.

<figure>
|                       | Singular | Plural     |
|----------------------:|:---------|:-----------|
|   Nominative #!(NOM)! | «nú»     | «nú·l»     |
|     Genitive #!(GEN)! | «nú·t»   | «nú·t·ł»   |
|   Comitative #!(COM)! | «nú·kas» | «nú·kas·ł» |
|     Caritive #!(CAR)! | «nú·ssa» | «nú·ssa·l» |
| Instrumental #!(INS)! | «nú·la»  | «nú·la·l»  |
|       Essive #!(ESS)! | «nú·gu»  | «nú·gu·l»  |
|  Translative #!(TRA)! | «nú·sti» | «nú·sti·l» |
|     Exessive #!(EXE)! | «nú·ču»  | «nú·ču·l»  |

|        | Singular      | Plural          |
|-------:|:--------------|:----------------|
| #!NOM! | «lun»         | «lun·ł»         |
| #!GEN! | «lu~~n~~·t»   | «lun·t·ł»       |
| #!COM! | «lun·kas»     | «lun·kas·ł»     |
| #!CAR! | «lu~~n~~·ssa» | «lu~~n~~·ssa·l» |
| #!INS! | «lun·la»      | «lun·la·l»      |
| #!ESS! | «lun·gu»      | «lun·gu·l»      |
| #!TRA! | «lu~~n~~·sti» | «lu~~n~~·sti·l» |
| #!EXE! | «lun·ču»      | «lun·ču·l»      |

</figure>

The _nominative_ is the subject of sentences, and the unmarked form. The _genitive_ is used for the object of sentences, the possessive, and for modifying other nouns (see [below](#adjectivals)).


<figure class=glosses>
```gloss
Jánim línait bairusi.
Jáni-m    línai-t    bairu-si
John-DEF  mouse-GEN  see-RPST
John saw a mouse.
```

```gloss
Jánimat línai
Jáni-ma-t     línai
John-DEF-GEN  mouse
John's mouse
```

```gloss
ausut línai
ausu-t     línai
large-GEN  mouse
a large mouse
```
</figure>

For _inalienable_ possession (body parts, family members, etc), the [definite](#definiteness) is usually used instead of an explicit genitive construction.

<figure class=glosses>
```gloss
Nattumatł bairusina.
nattu-ma-t-ł      bairu-si-na
parent-DEF-GEN-PL see-PST-1SG
I saw my [the] parents.
```
</figure>

The _comitative_ case is used for 'and' between two nouns, as well as 'with' in the sense of 'accompanied by'. It is used on all but the _last_ noun being conjoined, with the last one taking the semantic case for the whole sequence. The opposite case, the _caritive_, means 'without', and is also used for _negative_ possessive statements. (See the adessive, described below, for affirmative statements.)

<figure class=glosses>
```gloss
suksł ká
suksł ká
they;COM I
they and I
```

```gloss
Kalńkas þasit bairusina.
kalń-kas þasi-t  bairu-si-na
cat-COM  dog-GEN see-RPST-1SG
I saw a cat and a dog.
```

```gloss
Sairiassa aina.
sairia-ssa ai-na
money-CAR  be-1SG
I don't have any money.
```

```gloss
Kat fadaukas ká rut ǧimamlis šikkúsi.
kat fadau-kas ká rut ǧima-m-li-s šikkú-si
my friend-COM I his house-DEF-IN-LAT go-RPST
I went with my friend to his house.
```
</figure>


The most common use of the _instrumental_ case is the [theme] of ditransitive sentences (while the recipient is in the genitive). It is also used for 'with' as in 'using', in distributive phrases such as «kallila» 'in threes, in sets of three, three each', for quantity expressions such as units, and quantifiers like 'every'.

[theme]: https://en.wikipedia.org/wiki/Secundative_language

<figure class=glosses>
```gloss
Sanǧula paraina.
sanǧu-la parai-na
pen-INS    write-1SG
I write with a pen.
```

```gloss
kalli litrala tippi
kalli litra-la tippi
three litre-INS  water
three litres of water
```

```gloss
nakasnala hámal
nakasnala háma-l
every;INS   country-PL
every country
```

```gloss
nala  núl
nala  nú-l
any;INS person-PL
some people
```

```gloss
nai rala númł
nai ra(n)-la nú-m-ł
one thing-INS  person-DEF-PL
one of the people
```

```gloss
nala  númł
nala  nú-m-ł
any;INS person-DEF-PL
some of the people
```
</figure>

The _essive_ case indicates a state, while the _translative_ and _exessive_ cases indicate a change of state. The translative marks the new state, and the exessive the old. The essive and exessive are most commonly used with comparatives (see [below](#adjectivals)).

__TODO: examples__

# Locational cases

The locational cases are formed by pairs of suffixes, one for the type of
motion and one for the orientation or part of the target object.[^tsez]
Unlike for the core cases, the endings are the same regardless of whether the
stem ends in a consonant or vowel, so they are only listed for «nú».

These cases have formulaic names, e.g., 'adessive' (at), 'absuperlative' (from above), and so on.

[^tsez]: You might think that this sounds too mathematical or artificial to occur in a natural language, but in fact some Caucasian languages, such as [Tsez] and [Archi], do exactly this.

[Tsez]: http://en.wikipedia.org/wiki/Tsez_language "Tsez on Wikipedia"
[Archi]: http://en.wikipedia.org/wiki/Archi_language "Archi on Wikipedia"

* _ad--_ (_al--_): 'at'
* _in--_ (_il--_): 'in'
* _pre--_: 'in front of'
* _post--_: 'behind'
* _inter--_: 'between' or 'among'
* _super--_: 'on top of' or 'over'
* _sub--_: 'below' or 'under'
* _apud--_: 'near' or 'next to'
* _--essive_: 'at' or 'on'
* _--lative_: 'towards'
* _ab--lative_: 'away from'
* _per--lative_: 'through' or 'along'

<figure>
|            |       | Essive (ESS) | Lative (LAT) | Ab--lative (ABL) | Per--lative (PRL) |
|-----------:|------:|--------------|--------------|------------------|-------------------|
|        Ad– | #!SG! | «nú·sa»      | «nú·sa·s»    | «nú·sa·n»        | «nú·sa·ri»        |
|    #!(AD)! | #!PL! | «nú·sa·l»    | «nú·sa·s·ł»  | «nú·sa·n·ł»      | «nú·sa·ri·l»      |
|        In– | #!SG! | «nú·li»      | «nú·li·s»    | «nú·li·n»        | «nú·li·ri»        |
|    #!(IN)! | #!PL! | «nú·li·l»    | «nú·li·s·ł»  | «nú·li·n·ł»      | «nú·li·ri·l»      |
|       Pre– | #!SG! | «nú·ðu»      | «nú·ðu·s»    | «nú·ðu·n»        | «nú·ðu·ri»        |
|   #!(PRE)! | #!PL! | «nú·ðu·l»    | «nú·ðu·s·ł»  | «nú·ðu·n·ł»      | «nú·ðu·ri·l»      |
|      Post– | #!SG! | «nú·gi»      | «nú·gi·s»    | «nú·gi·n»        | «nú·gi·ri»        |
|  #!(POST)! | #!PL! | «nú·gi·l»    | «nú·gi·s·ł»  | «nú·gi·n·ł»      | «nú·gi·ri·l»      |
|     Inter– | #!SG! | «nú·nua»     | «nú·nua·s»   | «nú·nua·n»       | «nú·nua·ri»       |
| #!(INTER)! | #!PL! | «nú·nua·l»   | «nú·nua·s·ł» | «nú·nua·n·ł»     | «nú·nua·ri·l»     |
|     Super– | #!SG! | «nú·ba»      | «nú·ba·s»    | «nú·ba·n»        | «nú·ba·ri»        |
| #!(SUPER)! | #!PL! | «nú·ba·l»    | «nú·ba·s·ł»  | «nú·ba·n·ł»      | «nú·ba·ri·l»      |
|       Sub– | #!SG! | «nú·ku»      | «nú·ku·s»    | «nú·ku·n»        | «nú·ku·ri»        |
|   #!(SUB)! | #!PL! | «nú·ku·l»    | «nú·ku·s·ł»  | «nú·ku·n·ł»      | «nú·ku·ri·l»      |
|      Apud– | #!SG! | «nú·mi»      | «nú·mi·s»    | «nú·mi·n»        | «nú·mi·ri»        |
|  #!(APUD)! | #!PL! | «nú·mi·l»    | «nú·mi·s·ł»  | «nú·mi·n·ł»      | «nú·mi·ri·l»      |

</figure>

* Subessive is used for:
    * 'in the opinion of': «Kaku manifnut ai.» That's pleasant to me/I like that.
- Superessive is used for:
    - 'about': «Suba jaisi fína.» I dreamt about you.

<!-- -->

* \#!(AD--LAT)! «Dufnamsas júlisina.» I stuck it onto the wall.
* \#!(AD--ESS)! «Ǧimamsa aihapa?» Are you at home?
* \#!(IN--LAT)! «Sihamgit ǧimamlis šikkúmána.» I'll be going home soon.
* \#!(PRE--PRL)! «Sabut kalń káðuri narasi.» A black cat passed in front of me.
* \#!(POST--ESS)! «Ǧimamgi waibifás.» They're playing round the back of the house.
* \#!(AD--PRL)! «Lunsari šikkúsina.» I went down the road.
* \#!(IN--PRL)! «Lunliri šikkúsina.» I went across the road.
* \#!(APUD--PRL)! «Lunmiri šikkúsina.» I followed (alongside) the river.


The orientation suffixes give rise to the following words:

<div class=twocol>
- «fansað»: surface
- «fanlið»: interior
- «fanduð»: front
- «fangið»: back
- «fannuað»: company
- «fambað»: top
- «fankuð»: bottom
- «fammið»: vicinity
</div>


# Definiteness

The definite suffix for nouns (DEF) is «-m», and is used more frequently than 'the' in English. For example, in the second sentence below Sam has one dog, and in the third he is implied to have several. The names of people and places are also definite.

After a consonant or «-ń», the definite suffix is «-ḿ»; the sequence «ńḿ» is pronounced as a single syllable, as #/nm̩/. After «-m» or «-ḿ», the suffix is «-am». The definite suffix occurs _between_ the stem and the case ending. Between the «-m» form and a case suffix starting with a consonant cluster, or the genitive singular «-t», an extra epenthetic «-a» is added.

<figure class=glosses>
```gloss
guwanḿt samńḿ
guwan-ḿ-t samń-ḿ
sun-DEF-GEN colour-DEF
the colour of the sun
```
```gloss
Sámimat þasi
Sami-ma-t þasi
Sam-DEF-GEN dog
one of Sam's dogs
```
```gloss
Sámimat þasim
Sami-ma-t þasim
Sam-DEF-GEN dog-DEF
Sam's dog
```
</figure>

The definite suffix is used:

* When the referent is old information already mentioned.  
  «Pas nú bairusina. Nai rala núm manifnut gašnat ippausi.» I saw two people. One of them was wearing a nice shirt.

* For people, places, countries, and other proper names.  
  «Danielḿ Włjáhámamli nuabia.» Daniel lives in Austria.

* In time phrases with «gimi».  
  «Gimimli lána.» I'm doing it now.  
  However, «naigimi» 'sometime' is indefinite.  
  «Naigimili lámána.» I'll do it at some point.

* In statements of general fact.  
  «Númsal pasla aðal ai.» Humans have two eyes.

* __TODO: ?__

The definite suffix is _not_ used (in contrast to English):

* In superlatives.  
  «Milnutlit aifa.» It's the smallest.

* __TODO: ?__

# Adjectivals

Most words considered as adjectives in other languages are in fact grammatically nouns in Lántas; words such as «sabu» can be translated as 'the colour black'. When one noun modifies another attributively, the [genitive case](#corecases) suffix «-(a)t» is used. Additional adjectives after the first additionally take a special conjunctive suffix «-as», similar to the comitative case. Adjectives, like other noun modifiers, precede the head noun in most cases. However, they can follow it if they indicate a property considered inherent to the objects in question.

Genitive forms can be used as adverbs with the suffix «-tta»; the conjunctive variant is «-ttás».

<figure class=glosses>
```gloss
sabut þasi
sabu-t    þasi
black-GEN dog
a black dog
```
```gloss
líbisat þasi
líbis-at  þasi
happy-GEN dog
a happy dog
```
```gloss
sabut líbistas þasi
sabu-t    líbis-t-as     þasi
black-GEN happy-GEN-CONJ dog
a happy black dog
```
```gloss
Línaim sihatta irhi.
línai-m   siha-tta  irhi
mouse-GEN small-ADV squeak
The mouse is squeaking quietly.
```
</figure>

From adjectivals, several further derivations can be made: the _equative_, which expresses that two objects have an equal measure of some property; the _comparative_, which says that one object has more of a property than another object; and the _superlative_, which claims that an object has the most of a property. Derivation from «gaisi» 'white':

<figure>
------------------- --------------
     Equative (EQU) «gaisi·t·sat»
  Comparative (CMP) «gaisi·t·pat»
 Superlative (SUPL) «gaisi·t·lit»
------------------- --------------
</figure>

The noun being compared with is in the [essive case](#corecases) for the equative, and the exessive for the comparative.

<figure class=glosses>
```gloss
ǧimagu ausutsat
ǧima-gu  ausu-t-sat
house-ESS big-GEN-EQU
as big as a house
```
```gloss
fíraču panísatpat
fíra-ču panísa-t-pat
sky-EXE blue-GEN-CMP
bluer than the sky
```
</figure>
